Module: Google::Apis::BiglakeV1
- Defined in:
- lib/google/apis/biglake_v1.rb,
lib/google/apis/biglake_v1/classes.rb,
lib/google/apis/biglake_v1/service.rb,
lib/google/apis/biglake_v1/gem_version.rb,
lib/google/apis/biglake_v1/representations.rb
Overview
Lakehouse API
The Lakehouse API (formerly BigLake API) provides access to a serverless, fully managed, and highly available metastore that provides a single source of truth for your data lakehouse. It lets multiple engines—including Apache Spark, Google Managed Spark, Apache Flink, Trino and BigQuery—share tables and metadata for key open formats (Apache Iceberg, Apache Hive), and query the same copy of data. Plus, through the Lakehouse runtime catalog federation seamlessly unite your lakehouse ecosystem, letting Iceberg compatible engines on Google Cloud (BigQuery, Google Managed Spark) discover and analyze enterprise data across Snowflake, Databricks, and AWS Glue.
Defined Under Namespace
Classes: AuditConfig, AuditLogConfig, BigLakeServiceService, Binding, Catalog, Database, Expr, HiveDatabaseOptions, HiveTableOptions, ListCatalogsResponse, ListDatabasesResponse, ListTablesResponse, Policy, RenameTableRequest, SerDeInfo, SetIamPolicyRequest, StorageDescriptor, Table, TestIamPermissionsRequest, TestIamPermissionsResponse
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-biglake_v1 gem
"0.9.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260625"- VERSION =
Version of the Lakehouse API this client connects to. This is NOT the gem version.
'V1'- AUTH_BIGQUERY =
View and manage your data in Google BigQuery and see the email address for your Google Account
'https://www.googleapis.com/auth/bigquery'- AUTH_CLOUD_PLATFORM =
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
'https://www.googleapis.com/auth/cloud-platform'