Class: Google::Apis::BiglakeV1::StorageDescriptor

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/biglake_v1/classes.rb,
lib/google/apis/biglake_v1/representations.rb,
lib/google/apis/biglake_v1/representations.rb

Overview

Stores physical storage information of the data.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StorageDescriptor

Returns a new instance of StorageDescriptor.



702
703
704
# File 'lib/google/apis/biglake_v1/classes.rb', line 702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#input_formatString

The fully qualified Java class name of the input format. Corresponds to the JSON property inputFormat

Returns:

  • (String)


685
686
687
# File 'lib/google/apis/biglake_v1/classes.rb', line 685

def input_format
  @input_format
end

#location_uriString

Cloud Storage folder URI where the table data is stored, starting with "gs://". Corresponds to the JSON property locationUri

Returns:

  • (String)


690
691
692
# File 'lib/google/apis/biglake_v1/classes.rb', line 690

def location_uri
  @location_uri
end

#output_formatString

The fully qualified Java class name of the output format. Corresponds to the JSON property outputFormat

Returns:

  • (String)


695
696
697
# File 'lib/google/apis/biglake_v1/classes.rb', line 695

def output_format
  @output_format
end

#serde_infoGoogle::Apis::BiglakeV1::SerDeInfo

Serializer and deserializer information. Corresponds to the JSON property serdeInfo



700
701
702
# File 'lib/google/apis/biglake_v1/classes.rb', line 700

def serde_info
  @serde_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



707
708
709
710
711
712
# File 'lib/google/apis/biglake_v1/classes.rb', line 707

def update!(**args)
  @input_format = args[:input_format] if args.key?(:input_format)
  @location_uri = args[:location_uri] if args.key?(:location_uri)
  @output_format = args[:output_format] if args.key?(:output_format)
  @serde_info = args[:serde_info] if args.key?(:serde_info)
end