Class: Google::Apis::BiglakeV1::BigLakeServiceService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BiglakeV1::BigLakeServiceService
- Defined in:
- lib/google/apis/biglake_v1/service.rb
Overview
Lakehouse API
The Lakehouse API (formerly BigLake API) provides access to a serverless, fully managed, and highly available metastore that provides a single source of truth for your data lakehouse. It lets multiple engines—including Apache Spark, Google Managed Spark, Apache Flink, Trino and BigQuery—share tables and metadata for key open formats (Apache Iceberg, Apache Hive), and query the same copy of data. Plus, through the Lakehouse runtime catalog federation seamlessly unite your lakehouse ecosystem, letting Iceberg compatible engines on Google Cloud (BigQuery, Google Managed Spark) discover and analyze enterprise data across Snowflake, Databricks, and AWS Glue.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://biglake.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_catalog(parent, catalog_object = nil, catalog_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Creates a new catalog.
-
#create_project_location_catalog_database(parent, database_object = nil, database_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Creates a new database.
-
#create_project_location_catalog_database_table(parent, table_object = nil, table_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Creates a new table.
-
#delete_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Deletes an existing catalog specified by the catalog ID.
-
#delete_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Deletes an existing database specified by the database ID.
-
#delete_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Deletes an existing table specified by the table ID.
-
#get_project_catalog_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
-
#get_project_catalog_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
-
#get_project_catalog_namespace_table_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
-
#get_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Gets the catalog specified by the resource name.
-
#get_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Gets the database specified by the resource name.
-
#get_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Gets the table specified by the resource name.
-
#initialize ⇒ BigLakeServiceService
constructor
A new instance of BigLakeServiceService.
-
#list_project_location_catalog_database_tables(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListTablesResponse
List all tables in a specified database.
-
#list_project_location_catalog_databases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListDatabasesResponse
List all databases in a specified catalog.
-
#list_project_location_catalogs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListCatalogsResponse
List all catalogs in a specified project.
-
#patch_project_location_catalog_database(name, database_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Updates an existing database specified by the database ID.
-
#patch_project_location_catalog_database_table(name, table_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Updates an existing table specified by the table ID.
-
#rename_table(name, rename_table_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Renames an existing table specified by the table ID.
-
#set_catalog_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
-
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
-
#set_table_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
-
#test_catalog_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified catalog.
-
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified namespace.
-
#test_table_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified table.
Constructor Details
#initialize ⇒ BigLakeServiceService
Returns a new instance of BigLakeServiceService.
55 56 57 58 59 60 |
# File 'lib/google/apis/biglake_v1/service.rb', line 55 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-biglake_v1', client_version: Google::Apis::BiglakeV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
48 49 50 |
# File 'lib/google/apis/biglake_v1/service.rb', line 48 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
53 54 55 |
# File 'lib/google/apis/biglake_v1/service.rb', line 53 def quota_user @quota_user end |
Instance Method Details
#create_project_location_catalog(parent, catalog_object = nil, catalog_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Creates a new catalog.
429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/google/apis/biglake_v1/service.rb', line 429 def create_project_location_catalog(parent, catalog_object = nil, catalog_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/catalogs', ) command.request_representation = Google::Apis::BiglakeV1::Catalog::Representation command.request_object = catalog_object command.response_representation = Google::Apis::BiglakeV1::Catalog::Representation command.response_class = Google::Apis::BiglakeV1::Catalog command.params['parent'] = parent unless parent.nil? command.query['catalogId'] = catalog_id unless catalog_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_catalog_database(parent, database_object = nil, database_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Creates a new database.
570 571 572 573 574 575 576 577 578 579 580 581 |
# File 'lib/google/apis/biglake_v1/service.rb', line 570 def create_project_location_catalog_database(parent, database_object = nil, database_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/databases', ) command.request_representation = Google::Apis::BiglakeV1::Database::Representation command.request_object = database_object command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['parent'] = parent unless parent.nil? command.query['databaseId'] = database_id unless database_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_catalog_database_table(parent, table_object = nil, table_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Creates a new table.
753 754 755 756 757 758 759 760 761 762 763 764 |
# File 'lib/google/apis/biglake_v1/service.rb', line 753 def create_project_location_catalog_database_table(parent, table_object = nil, table_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/tables', ) command.request_representation = Google::Apis::BiglakeV1::Table::Representation command.request_object = table_object command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['parent'] = parent unless parent.nil? command.query['tableId'] = table_id unless table_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Deletes an existing catalog specified by the catalog ID.
463 464 465 466 467 468 469 470 471 |
# File 'lib/google/apis/biglake_v1/service.rb', line 463 def delete_project_location_catalog(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Catalog::Representation command.response_class = Google::Apis::BiglakeV1::Catalog command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Deletes an existing database specified by the database ID.
605 606 607 608 609 610 611 612 613 |
# File 'lib/google/apis/biglake_v1/service.rb', line 605 def delete_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Deletes an existing table specified by the table ID.
788 789 790 791 792 793 794 795 796 |
# File 'lib/google/apis/biglake_v1/service.rb', line 788 def delete_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_catalog_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
95 96 97 98 99 100 101 102 103 104 |
# File 'lib/google/apis/biglake_v1/service.rb', line 95 def get_project_catalog_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_catalog_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
209 210 211 212 213 214 215 216 217 218 |
# File 'lib/google/apis/biglake_v1/service.rb', line 209 def get_project_catalog_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_catalog_namespace_table_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
323 324 325 326 327 328 329 330 331 332 |
# File 'lib/google/apis/biglake_v1/service.rb', line 323 def get_project_catalog_namespace_table_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Gets the catalog specified by the resource name.
494 495 496 497 498 499 500 501 502 |
# File 'lib/google/apis/biglake_v1/service.rb', line 494 def get_project_location_catalog(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Catalog::Representation command.response_class = Google::Apis::BiglakeV1::Catalog command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Gets the database specified by the resource name.
637 638 639 640 641 642 643 644 645 |
# File 'lib/google/apis/biglake_v1/service.rb', line 637 def get_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Gets the table specified by the resource name.
820 821 822 823 824 825 826 827 828 |
# File 'lib/google/apis/biglake_v1/service.rb', line 820 def get_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_catalog_database_tables(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListTablesResponse
List all tables in a specified database.
862 863 864 865 866 867 868 869 870 871 872 873 |
# File 'lib/google/apis/biglake_v1/service.rb', line 862 def list_project_location_catalog_database_tables(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/tables', ) command.response_representation = Google::Apis::BiglakeV1::ListTablesResponse::Representation command.response_class = Google::Apis::BiglakeV1::ListTablesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_catalog_databases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListDatabasesResponse
List all databases in a specified catalog.
676 677 678 679 680 681 682 683 684 685 686 |
# File 'lib/google/apis/biglake_v1/service.rb', line 676 def list_project_location_catalog_databases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/databases', ) command.response_representation = Google::Apis::BiglakeV1::ListDatabasesResponse::Representation command.response_class = Google::Apis::BiglakeV1::ListDatabasesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_catalogs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListCatalogsResponse
List all catalogs in a specified project.
533 534 535 536 537 538 539 540 541 542 543 |
# File 'lib/google/apis/biglake_v1/service.rb', line 533 def list_project_location_catalogs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/catalogs', ) command.response_representation = Google::Apis::BiglakeV1::ListCatalogsResponse::Representation command.response_class = Google::Apis::BiglakeV1::ListCatalogsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_catalog_database(name, database_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Updates an existing database specified by the database ID.
714 715 716 717 718 719 720 721 722 723 724 725 |
# File 'lib/google/apis/biglake_v1/service.rb', line 714 def patch_project_location_catalog_database(name, database_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BiglakeV1::Database::Representation command.request_object = database_object command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_catalog_database_table(name, table_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Updates an existing table specified by the table ID.
902 903 904 905 906 907 908 909 910 911 912 913 |
# File 'lib/google/apis/biglake_v1/service.rb', line 902 def patch_project_location_catalog_database_table(name, table_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BiglakeV1::Table::Representation command.request_object = table_object command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rename_table(name, rename_table_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Renames an existing table specified by the table ID.
938 939 940 941 942 943 944 945 946 947 948 |
# File 'lib/google/apis/biglake_v1/service.rb', line 938 def rename_table(name, rename_table_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:rename', ) command.request_representation = Google::Apis::BiglakeV1::RenameTableRequest::Representation command.request_object = rename_table_request_object command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_catalog_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/google/apis/biglake_v1/service.rb', line 129 def set_catalog_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BiglakeV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/google/apis/biglake_v1/service.rb', line 243 def set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BiglakeV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_table_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/google/apis/biglake_v1/service.rb', line 357 def set_table_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BiglakeV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_catalog_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified catalog.
164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/google/apis/biglake_v1/service.rb', line 164 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BiglakeV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BiglakeV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BiglakeV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified namespace.
278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/biglake_v1/service.rb', line 278 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BiglakeV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BiglakeV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BiglakeV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_table_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified table.
392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/google/apis/biglake_v1/service.rb', line 392 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BiglakeV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BiglakeV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BiglakeV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |