Class: Google::Apis::BiglakeV1::BigLakeServiceService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::BiglakeV1::BigLakeServiceService
- Defined in:
- lib/google/apis/biglake_v1/service.rb
Overview
BigLake API
The BigLake API provides access to BigLake Metastore, a serverless, fully managed, and highly available metastore for open-source data that can be used for querying Apache Iceberg tables in BigQuery.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://biglake.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_project_location_catalog(parent, catalog_object = nil, catalog_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Creates a new catalog.
-
#create_project_location_catalog_database(parent, database_object = nil, database_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Creates a new database.
-
#create_project_location_catalog_database_table(parent, table_object = nil, table_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Creates a new table.
-
#delete_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Deletes an existing catalog specified by the catalog ID.
-
#delete_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Deletes an existing database specified by the database ID.
-
#delete_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Deletes an existing table specified by the table ID.
-
#get_project_catalog_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
-
#get_project_catalog_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
-
#get_project_catalog_namespace_table_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
-
#get_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Gets the catalog specified by the resource name.
-
#get_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Gets the database specified by the resource name.
-
#get_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Gets the table specified by the resource name.
-
#initialize ⇒ BigLakeServiceService
constructor
A new instance of BigLakeServiceService.
-
#list_project_location_catalog_database_tables(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListTablesResponse
List all tables in a specified database.
-
#list_project_location_catalog_databases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListDatabasesResponse
List all databases in a specified catalog.
-
#list_project_location_catalogs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListCatalogsResponse
List all catalogs in a specified project.
-
#patch_project_location_catalog_database(name, database_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Updates an existing database specified by the database ID.
-
#patch_project_location_catalog_database_table(name, table_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Updates an existing table specified by the table ID.
-
#rename_table(name, rename_table_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Renames an existing table specified by the table ID.
-
#set_catalog_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
-
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
-
#set_table_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
-
#test_catalog_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified catalog.
-
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified namespace.
-
#test_table_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified table.
Constructor Details
#initialize ⇒ BigLakeServiceService
Returns a new instance of BigLakeServiceService.
49 50 51 52 53 54 |
# File 'lib/google/apis/biglake_v1/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-biglake_v1', client_version: Google::Apis::BiglakeV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/biglake_v1/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/biglake_v1/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#create_project_location_catalog(parent, catalog_object = nil, catalog_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Creates a new catalog.
423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/google/apis/biglake_v1/service.rb', line 423 def create_project_location_catalog(parent, catalog_object = nil, catalog_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/catalogs', ) command.request_representation = Google::Apis::BiglakeV1::Catalog::Representation command.request_object = catalog_object command.response_representation = Google::Apis::BiglakeV1::Catalog::Representation command.response_class = Google::Apis::BiglakeV1::Catalog command.params['parent'] = parent unless parent.nil? command.query['catalogId'] = catalog_id unless catalog_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_catalog_database(parent, database_object = nil, database_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Creates a new database.
564 565 566 567 568 569 570 571 572 573 574 575 |
# File 'lib/google/apis/biglake_v1/service.rb', line 564 def create_project_location_catalog_database(parent, database_object = nil, database_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/databases', ) command.request_representation = Google::Apis::BiglakeV1::Database::Representation command.request_object = database_object command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['parent'] = parent unless parent.nil? command.query['databaseId'] = database_id unless database_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_catalog_database_table(parent, table_object = nil, table_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Creates a new table.
747 748 749 750 751 752 753 754 755 756 757 758 |
# File 'lib/google/apis/biglake_v1/service.rb', line 747 def create_project_location_catalog_database_table(parent, table_object = nil, table_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+parent}/tables', ) command.request_representation = Google::Apis::BiglakeV1::Table::Representation command.request_object = table_object command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['parent'] = parent unless parent.nil? command.query['tableId'] = table_id unless table_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Deletes an existing catalog specified by the catalog ID.
457 458 459 460 461 462 463 464 465 |
# File 'lib/google/apis/biglake_v1/service.rb', line 457 def delete_project_location_catalog(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Catalog::Representation command.response_class = Google::Apis::BiglakeV1::Catalog command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Deletes an existing database specified by the database ID.
599 600 601 602 603 604 605 606 607 |
# File 'lib/google/apis/biglake_v1/service.rb', line 599 def delete_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Deletes an existing table specified by the table ID.
782 783 784 785 786 787 788 789 790 |
# File 'lib/google/apis/biglake_v1/service.rb', line 782 def delete_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_catalog_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
89 90 91 92 93 94 95 96 97 98 |
# File 'lib/google/apis/biglake_v1/service.rb', line 89 def get_project_catalog_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_catalog_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/google/apis/biglake_v1/service.rb', line 203 def get_project_catalog_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_catalog_namespace_table_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Gets the IAM policy for the specified Catalog.
317 318 319 320 321 322 323 324 325 326 |
# File 'lib/google/apis/biglake_v1/service.rb', line 317 def get_project_catalog_namespace_table_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_catalog(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Catalog
Gets the catalog specified by the resource name.
488 489 490 491 492 493 494 495 496 |
# File 'lib/google/apis/biglake_v1/service.rb', line 488 def get_project_location_catalog(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Catalog::Representation command.response_class = Google::Apis::BiglakeV1::Catalog command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Gets the database specified by the resource name.
631 632 633 634 635 636 637 638 639 |
# File 'lib/google/apis/biglake_v1/service.rb', line 631 def get_project_location_catalog_database(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Gets the table specified by the resource name.
814 815 816 817 818 819 820 821 822 |
# File 'lib/google/apis/biglake_v1/service.rb', line 814 def get_project_location_catalog_database_table(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_catalog_database_tables(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListTablesResponse
List all tables in a specified database.
856 857 858 859 860 861 862 863 864 865 866 867 |
# File 'lib/google/apis/biglake_v1/service.rb', line 856 def list_project_location_catalog_database_tables(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/tables', ) command.response_representation = Google::Apis::BiglakeV1::ListTablesResponse::Representation command.response_class = Google::Apis::BiglakeV1::ListTablesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_catalog_databases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListDatabasesResponse
List all databases in a specified catalog.
670 671 672 673 674 675 676 677 678 679 680 |
# File 'lib/google/apis/biglake_v1/service.rb', line 670 def list_project_location_catalog_databases(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/databases', ) command.response_representation = Google::Apis::BiglakeV1::ListDatabasesResponse::Representation command.response_class = Google::Apis::BiglakeV1::ListDatabasesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_catalogs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::ListCatalogsResponse
List all catalogs in a specified project.
527 528 529 530 531 532 533 534 535 536 537 |
# File 'lib/google/apis/biglake_v1/service.rb', line 527 def list_project_location_catalogs(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+parent}/catalogs', ) command.response_representation = Google::Apis::BiglakeV1::ListCatalogsResponse::Representation command.response_class = Google::Apis::BiglakeV1::ListCatalogsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_catalog_database(name, database_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Database
Updates an existing database specified by the database ID.
708 709 710 711 712 713 714 715 716 717 718 719 |
# File 'lib/google/apis/biglake_v1/service.rb', line 708 def patch_project_location_catalog_database(name, database_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BiglakeV1::Database::Representation command.request_object = database_object command.response_representation = Google::Apis::BiglakeV1::Database::Representation command.response_class = Google::Apis::BiglakeV1::Database command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_catalog_database_table(name, table_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Updates an existing table specified by the table ID.
896 897 898 899 900 901 902 903 904 905 906 907 |
# File 'lib/google/apis/biglake_v1/service.rb', line 896 def patch_project_location_catalog_database_table(name, table_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1/{+name}', ) command.request_representation = Google::Apis::BiglakeV1::Table::Representation command.request_object = table_object command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#rename_table(name, rename_table_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Table
Renames an existing table specified by the table ID.
932 933 934 935 936 937 938 939 940 941 942 |
# File 'lib/google/apis/biglake_v1/service.rb', line 932 def rename_table(name, rename_table_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+name}:rename', ) command.request_representation = Google::Apis::BiglakeV1::RenameTableRequest::Representation command.request_object = rename_table_request_object command.response_representation = Google::Apis::BiglakeV1::Table::Representation command.response_class = Google::Apis::BiglakeV1::Table command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_catalog_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/google/apis/biglake_v1/service.rb', line 123 def set_catalog_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BiglakeV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/google/apis/biglake_v1/service.rb', line 237 def set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BiglakeV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_table_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::Policy
Sets the IAM policy for the specified catalog.
351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/google/apis/biglake_v1/service.rb', line 351 def set_table_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::BiglakeV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::BiglakeV1::Policy::Representation command.response_class = Google::Apis::BiglakeV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_catalog_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified catalog.
158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/google/apis/biglake_v1/service.rb', line 158 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BiglakeV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BiglakeV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BiglakeV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified namespace.
272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/google/apis/biglake_v1/service.rb', line 272 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BiglakeV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BiglakeV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BiglakeV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_table_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::BiglakeV1::TestIamPermissionsResponse
Tests the IAM permissions for the specified table.
386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/google/apis/biglake_v1/service.rb', line 386 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::BiglakeV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::BiglakeV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::BiglakeV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |