Class: Google::Apis::BiglakeV1::Table
- Inherits:
-
Object
- Object
- Google::Apis::BiglakeV1::Table
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/biglake_v1/classes.rb,
lib/google/apis/biglake_v1/representations.rb,
lib/google/apis/biglake_v1/representations.rb
Overview
Represents a table.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#etag ⇒ String
The checksum of a table object computed by the server based on the value of other fields.
-
#expire_time ⇒ String
Output only.
-
#hive_options ⇒ Google::Apis::BiglakeV1::HiveTableOptions
Options of a Hive table.
-
#name ⇒ String
Output only.
-
#type ⇒ String
The table type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Table
constructor
A new instance of Table.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Table
Returns a new instance of Table.
766 767 768 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation time of the table.
Corresponds to the JSON property createTime
722 723 724 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 722 def create_time @create_time end |
#delete_time ⇒ String
Output only. The deletion time of the table. Only set after the table is
deleted.
Corresponds to the JSON property deleteTime
728 729 730 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 728 def delete_time @delete_time end |
#etag ⇒ String
The checksum of a table object computed by the server based on the value of
other fields. It may be sent on update requests to ensure the client has an up-
to-date value before proceeding. It is only checked for update table
operations.
Corresponds to the JSON property etag
736 737 738 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 736 def etag @etag end |
#expire_time ⇒ String
Output only. The time when this table is considered expired. Only set after
the table is deleted.
Corresponds to the JSON property expireTime
742 743 744 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 742 def expire_time @expire_time end |
#hive_options ⇒ Google::Apis::BiglakeV1::HiveTableOptions
Options of a Hive table.
Corresponds to the JSON property hiveOptions
747 748 749 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 747 def @hive_options end |
#name ⇒ String
Output only. The resource name. Format: projects/project_id_or_number/
locations/location_id/catalogs/catalog_id/databases/database_id/tables/
table_id
Corresponds to the JSON property name
754 755 756 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 754 def name @name end |
#type ⇒ String
The table type.
Corresponds to the JSON property type
759 760 761 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 759 def type @type end |
#update_time ⇒ String
Output only. The last modification time of the table.
Corresponds to the JSON property updateTime
764 765 766 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 764 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
771 772 773 774 775 776 777 778 779 780 |
# File 'lib/google/apis/biglake_v1/classes.rb', line 771 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @hive_options = args[:hive_options] if args.key?(:hive_options) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |